@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -32,7 +32,7 @@ ConfigureCustomSettingDialog::ConfigureCustomSettingDialog(QWidget *parent)
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     setWindowTitle(i18n("Add custom rule"));
 
-    mCustomSettingWidget = new ConfigureCustomSettingWidget;
+    mCustomSettingWidget = new ConfigureCustomSettingWidget(this);
     mCustomSettingWidget->setObjectName(QStringLiteral("customsettingwidget"));
     mainLayout->addWidget(mCustomSettingWidget);
 
@@ -44,12 +44,10 @@ ConfigureCustomSettingDialog::ConfigureCustomSettingDialog(QWidget *parent)
     buttonOk->setEnabled(false);
     connect(mCustomSettingWidget, &ConfigureCustomSettingWidget::enableButton, buttonOk, &QWidget::setEnabled);
     mainLayout->addWidget(buttonBox);
-
 }
 
 ConfigureCustomSettingDialog::~ConfigureCustomSettingDialog()
 {
-
 }
 
 void ConfigureCustomSettingDialog::setRule(const QString &rule)
