@@ -20,7 +20,9 @@
 
 #include "kdeapplicationtreelistwidget.h"
 #include "categorytypecombobox.h"
+#include "kdebugsettingsutil.h"
 #include <QHeaderView>
+#include <KLocalizedString>
 
 KDEApplicationTreeListWidgetItem::KDEApplicationTreeListWidgetItem(const QString &category, QTreeWidget *parent)
     : QTreeWidgetItem(parent)
@@ -64,7 +66,7 @@ LoggingCategory KDEApplicationTreeListWidgetItem::rule(bool forceSavingAllRules)
     LoggingCategory cat;
     if (mCategoryTypeCombobox->loggingCategoryIsNotDefault() || forceSavingAllRules) {
         cat.enabled = false;
-        cat.logName = mCategory;
+        cat.categoryName = mCategory;
         cat.loggingType = mCategoryTypeCombobox->type();
     }
     return cat;
@@ -73,8 +75,10 @@ LoggingCategory KDEApplicationTreeListWidgetItem::rule(bool forceSavingAllRules)
 KDEApplicationTreeListWidget::KDEApplicationTreeListWidget(QWidget *parent)
     : QTreeWidget(parent)
 {
-    setColumnCount(2);
+    setColumnCount(4);
     setRootIsDecorated(false);
+    setColumnHidden(KDEApplicationTreeListWidgetItem::LogName, true);
+    setColumnHidden(KDEApplicationTreeListWidgetItem::IdentifierName, true);
     header()->hide();
 }
 
@@ -82,11 +86,18 @@ KDEApplicationTreeListWidget::~KDEApplicationTreeListWidget()
 {
 }
 
+QList<int> KDEApplicationTreeListWidget::searchColumns() const
+{
+    return {KDEApplicationTreeListWidgetItem::Description, KDEApplicationTreeListWidgetItem::LogName, KDEApplicationTreeListWidgetItem::IdentifierName};
+}
+
 void KDEApplicationTreeListWidget::selectAllDebugCategories()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
         KDEApplicationTreeListWidgetItem *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
-        itemWidget->setType(LoggingCategory::Debug);
+        if (!itemWidget->isHidden()) {
+            itemWidget->setType(LoggingCategory::Debug);
+        }
     }
 }
 
@@ -94,7 +105,9 @@ void KDEApplicationTreeListWidget::deSelectAllDebugCategories()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
         KDEApplicationTreeListWidgetItem *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
-        itemWidget->setType(LoggingCategory::Info);
+        if (!itemWidget->isHidden()) {
+            itemWidget->setType(LoggingCategory::Info);
+        }
     }
 }
 
@@ -102,7 +115,9 @@ void KDEApplicationTreeListWidget::deSelectAllMessagesCategories()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
         KDEApplicationTreeListWidgetItem *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
-        itemWidget->setType(LoggingCategory::Off);
+        if (!itemWidget->isHidden()) {
+            itemWidget->setType(LoggingCategory::Off);
+        }
     }
 }
 
@@ -111,17 +126,29 @@ void KDEApplicationTreeListWidget::fillList(const LoggingCategory::List &list)
     addListItems(list, true);
 }
 
+QString KDEApplicationTreeListWidget::generateToolTip(const LoggingCategory &cat)
+{
+    QString toopTip = i18n("Category name: %1", cat.categoryName);
+    if (!cat.identifierName.isEmpty()) {
+        toopTip += QLatin1Char('\n') + i18n("Identifier: %1", cat.identifierName);
+    }
+    toopTip += QLatin1Char('\n') + i18n("Default Severity: %1", KDebugSettingsUtil::convertCategoryTypeToString(cat.defaultSeverityType));
+    return toopTip;
+}
+
 void KDEApplicationTreeListWidget::addListItems(const LoggingCategory::List &list, bool clearList)
 {
     if (clearList) {
         clear();
     }
     for (const LoggingCategory &cat : list) {
-        KDEApplicationTreeListWidgetItem *item = new KDEApplicationTreeListWidgetItem(cat.logName, this);
-        item->setToolTip(0, cat.logName);
+        KDEApplicationTreeListWidgetItem *item = new KDEApplicationTreeListWidgetItem(cat.categoryName, this);
+        item->setToolTip(0, generateToolTip(cat));
         item->setText(KDEApplicationTreeListWidgetItem::Description, cat.description);
         item->setType(cat.loggingType);
-        item->setDefaultCategory(cat.defaultCategoryType);
+        item->setDefaultCategory(cat.defaultSeverityType);
+        item->setText(KDEApplicationTreeListWidgetItem::LogName, cat.categoryName);
+        item->setText(KDEApplicationTreeListWidgetItem::IdentifierName, cat.identifierName);
     }
     resizeColumnToContents(KDEApplicationTreeListWidgetItem::Description);
 }
@@ -146,7 +173,6 @@ LoggingCategory::List KDEApplicationTreeListWidget::rules(bool forceSavingAllRul
 
 void KDEApplicationTreeListWidget::restoreToDefault()
 {
-    //TODO use default value
     for (int i = 0; i < topLevelItemCount(); ++i) {
         KDEApplicationTreeListWidgetItem *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
         itemWidget->restoreToDefault();
